
// Name        : Keith Vertanen
// Username    : kvertanen
// Description : Drive a box around the graphics window.  If you hit a wall,
//               velocity in the relevant direction stops.  Controls are:
//               w = up, s = down, a = left, d = right
//               Plays a crash sound if we hit a wall.
public class BoxCar
{   
    public static void main(String[] args)
    {
        // Start the car in the middle of the screen
        double carX = 0.5;
        double carY = 0.5;
        
        // A constant that controls how much velocity is changes per key hit
        final double VELOCITY_DELTA = 0.01;
        
        // How many milliseconds to sleep between frames of animation
        final int SLEEP_MS = 100;
        
        // Half the width/height of our square car
        final double HALF_CAR_SIZE = 0.05;

        // File containing the crash sound
        final String CRASH_SOUND = "explosion.wav";
                
        // Car start heading up
        double velocityX = 0.0;
        double velocityY = VELOCITY_DELTA;
        
        // Keep driving forever
        while (true)
        {
            // Erase the screen 
            StdDraw.setPenColor(StdDraw.WHITE);
            StdDraw.filledSquare(0.0, 0.0, 1.1);
        
            if (StdDraw.hasNextKeyTyped())
            {
                char ch = StdDraw.nextKeyTyped();            
                if (ch == 'w')
                {
                    // Go faster upwards
                    velocityY += VELOCITY_DELTA;
                }
                else if (ch == 's')
                {
                    // Go faster downwards
                    velocityY -= VELOCITY_DELTA;
                }
                else if (ch == 'd')
                {
                    // Go faster right
                    velocityX += VELOCITY_DELTA;
                }
                else if (ch == 'a')
                {
                    // Go faster left
                    velocityX -= VELOCITY_DELTA;
                }
            }
                        
            // Adjust the location of the car
            carX += velocityX;
            carY += velocityY;
            
            // See if we hit the left wall
            if (carX < HALF_CAR_SIZE)
            {
                carX = HALF_CAR_SIZE;
                velocityX = 0.0;
                StdAudio.play(CRASH_SOUND);
            }
            // Or the right wall
            else if (carX > (1.0 - HALF_CAR_SIZE))
            {
                carX = 1.0 - HALF_CAR_SIZE;
                velocityX = 0.0;           
                StdAudio.play(CRASH_SOUND); 
            }
            
            // See if we hit the top wall
            if (carY < HALF_CAR_SIZE)
            {
                carY = HALF_CAR_SIZE;
                velocityY = 0.0;
                StdAudio.play(CRASH_SOUND);
            }
            // Or the bottom wall
            else if (carY > (1.0 - HALF_CAR_SIZE))
            {
                carY = 1.0 - HALF_CAR_SIZE;
                velocityY = 0.0;           
                StdAudio.play(CRASH_SOUND); 
            }

            // Now draw the red race car in its new location
            StdDraw.setPenColor(StdDraw.RED);
            StdDraw.filledSquare(carX, carY, HALF_CAR_SIZE);
            
            StdDraw.show(SLEEP_MS);
        }
    }

}
